Groups | Search | Server Info | Keyboard shortcuts | Login | Register [http] [https] [nntp] [nntps]


Groups > linux.kernel > #1323258

[PATCH v2 05/11] xen/hvmlite: HVMlite guests always have PV devices

From Boris Ostrovsky <boris.ostrovsky@oracle.com>
Newsgroups linux.kernel
Subject [PATCH v2 05/11] xen/hvmlite: HVMlite guests always have PV devices
Date 2016-02-01 16:50 +0100
Message-ID <qXoTP-4WL-55@gated-at.bofh.it> (permalink)
References <qXoTM-4WL-7@gated-at.bofh.it>
Organization linux.* mail to news gateway

Show all headers | View raw


Signed-off-by: Boris Ostrovsky <boris.ostrovsky@oracle.com>
---
 arch/x86/xen/platform-pci-unplug.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/arch/x86/xen/platform-pci-unplug.c b/arch/x86/xen/platform-pci-unplug.c
index 9586ff3..802ec90 100644
--- a/arch/x86/xen/platform-pci-unplug.c
+++ b/arch/x86/xen/platform-pci-unplug.c
@@ -73,8 +73,8 @@ bool xen_has_pv_devices(void)
 	if (!xen_domain())
 		return false;
 
-	/* PV domains always have them. */
-	if (xen_pv_domain())
+	/* PV and HVMlite domains always have them. */
+	if (xen_pv_domain() || xen_hvmlite)
 		return true;
 
 	/* And user has xen_platform_pci=0 set in guest config as
-- 
1.7.1

Back to linux.kernel | Previous | Next | Find similar | Unroll thread


Thread

[PATCH v2 05/11] xen/hvmlite: HVMlite guests always have PV devices Boris Ostrovsky <boris.ostrovsky@oracle.com> - 2016-02-01 16:50 +0100

csiph-web